Class: String
Instance Method Summary collapse
-
#blank? ⇒ Boolean
Strings are blank if they are empty or include only whitespace.
Instance Method Details
#blank? ⇒ Boolean
Strings are blank if they are empty or include only whitespace
47 48 49 |
# File 'lib/blank.rb', line 47 def blank? strip.empty? end |